Index: test/mjsunit/regress/regress-embedded-cons-string.js |
diff --git a/test/mjsunit/regress/regress-embedded-cons-string.js b/test/mjsunit/regress/regress-embedded-cons-string.js |
index 6a63da2fde0c332b58df653682c514670e3d1570..58a0b1c86960fc93005390dda0c9a375ebd08335 100644 |
--- a/test/mjsunit/regress/regress-embedded-cons-string.js |
+++ b/test/mjsunit/regress/regress-embedded-cons-string.js |
@@ -27,27 +27,27 @@ |
// Flags: --fold-constants --nodead-code-elimination |
// Flags: --expose-gc --allow-natives-syntax |
-// Flags: --parallel-recompilation --parallel-recompilation-delay=300 |
+// Flags: --concurrent-recompilation --concurrent-recompilation-delay=300 |
-if (!%IsParallelRecompilationSupported()) { |
- print("Parallel recompilation is disabled. Skipping this test."); |
+if (!%IsConcurrentRecompilationSupported()) { |
+ print("Concurrent recompilation is disabled. Skipping this test."); |
quit(); |
} |
function test(fun) { |
fun(); |
fun(); |
// Mark for parallel optimization. |
%OptimizeFunctionOnNextCall(fun, "parallel"); |
//Trigger optimization in the background. |
fun(); |
//Tenure cons string. |
gc(); |
// In the mean time, parallel recompiling is not complete yet. |
assertUnoptimized(fun, "no sync"); |
// Parallel recompilation eventually finishes and embeds tenured cons string. |
assertOptimized(fun, "sync"); |
- //Visit embedded cons string during mark compact. |
+ // Visit embedded cons string during mark compact. |
gc(); |
} |
@@ -27,27 +27,27 @@ |
fun(); |
fun(); |
- // Mark for parallel optimization. |
- %OptimizeFunctionOnNextCall(fun, "parallel"); |
+ // Mark for concurrent optimization. |
+ %OptimizeFunctionOnNextCall(fun, "concurrent"); |
//Trigger optimization in the background. |
fun(); |
@@ -27,27 +27,27 @@ |
//Tenure cons string. |
gc(); |
- // In the mean time, parallel recompiling is not complete yet. |
+ // In the mean time, concurrent recompiling is not complete yet. |
assertUnoptimized(fun, "no sync"); |
@@ -27,27 +27,27 @@ |
assertUnoptimized(fun, "no sync"); |
- // Parallel recompilation eventually finishes and embeds tenured cons string. |
+ // Concurrent recompilation eventually finishes, embeds tenured cons string. |
assertOptimized(fun, "sync"); |